@@ -255,6 +255,9 @@ NR_bkl = function(..., use_mean = FALSE)
 
 calibrate_CML <- function(scoretab, design, sufI, a, first, last, nIter, fixed_b=NULL,progress = show_progress()) 
 {
+  if(tolower(Sys.info()['sysname'])=='sunos'){
+    return(calibrate_CML_sol(scoretab, design, sufI, a, first, last, nIter, fixed_b))
+  }
   
   use_mean = FALSE
   # perhaps this first part should be moved to fit_enorm
@@ -307,19 +310,6 @@ calibrate_CML <- function(scoretab, design, sufI, a, first, last, nIter, fixed_b
       converged=(max(abs(sufI-EsufI))/nn < 1e-04)
       if(is.na(converged))
       {
-        if(tolower(Sys.info())=='sunos')
-        {
-          # we have no idea what goes wrong on solaris so if the error is still there  we give a 
-          # specific eror message to see what happens on cran (desperation)
-          if(any(is.nan(EsufI)))
-            stop("Solaris: E.step returns NaN values")
-          if(anyNA(EsufI))
-            stop("Solaris: E.step returns NA values")
-          if(any(!is.finite(EsufI)))
-            stop("Solaris: E.step returns infinite values")
-          stop("Solaris: converged is NA after e.step")
-        }
-        
         if(use_mean)
           stop('problem cannot be computed')
         # continue with the next iteration using elsym_mean
@@ -373,24 +363,6 @@ calibrate_CML <- function(scoretab, design, sufI, a, first, last, nIter, fixed_b
       
       if(inherits(nb,'try-error') || is.na(converged))
       {
-        if(tolower(Sys.info())=='sunos')
-        {
-          # we have no idea what goes wrong on solaris so if the error is still there  we give a 
-          # specific eror message to see what happens on cran (desperation)
-          if(inherits(nb,'try-error'))
-            stop(nb)
-          
-          if(any(is.nan(EsufI)))
-            stop("Solaris: H.step returns NaN values")
-          if(anyNA(EsufI))
-            stop("Solaris: H.step returns NA values")
-          if(any(!is.finite(EsufI)))
-            stop("Solaris: H.step returns infinite values")
-          stop("Solaris: converged is NA after e.step")
-        }
-        
-        
-        
         if(use_mean)
           stop('problem cannot be computed')
         # continue with the next iteration using elsym_mean
